pub struct Client { /* private fields */ }Expand description
Client for AWS Certificate Manager
Client for invoking operations on AWS Certificate Manager. Each operation on AWS Certificate Manager is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Constructing a Client
A Config is required to construct a client. For most use cases, the aws-config
crate should be used to automatically resolve this config using
aws_config::load_from_env(), since this will resolve an SdkConfig which can be shared
across multiple different AWS SDK clients. This config resolution process can be customized
by calling aws_config::from_env() instead, which returns a ConfigLoader that uses
the builder pattern to customize the default config.
In the simplest case, creating a client looks as follows:
let config = aws_config::load_from_env().await;
let client = aws_sdk_acm::Client::new(&config);Occasionally, SDKs may have additional service-specific values that can be set on the Config that
is absent from SdkConfig, or slightly different settings for a specific client may be desired.
The Builder struct implements From<&SdkConfig>, so setting these specific settings can be
done as follows:
let sdk_config = ::aws_config::load_from_env().await;
let config = aws_sdk_acm::config::Builder::from(&sdk_config)
.some_service_specific_setting("value")
.build();See the aws-config docs and Config for more information on customizing configuration.
Note: Client construction is expensive due to connection thread pool initialization, and should be done once at application start-up.
Using the Client
A client has a function for every operation that can be performed by the service.
For example, the AddTagsToCertificate operation has
a Client::add_tags_to_certificate, function which returns a builder for that operation.
The fluent builder ultimately has a send() function that returns an async future that
returns a result, as illustrated below:
let result = client.add_tags_to_certificate()
.certificate_arn("example")
.send()
.await;The underlying HTTP requests that get made by this can be modified with the customize_operation
function on the fluent builder. See the customize module for more
information.
Waiters
This client provides wait_until methods behind the Waiters trait.
To use them, simply import the trait, and then call one of the wait_until methods. This will
return a waiter fluent builder that takes various parameters, which are documented on the builder
type. Once parameters have been provided, the wait method can be called to initiate waiting.
For example, if there was a wait_until_thing method, it could look like:
let result = client.wait_until_thing()
.thing_id("someId")
.wait(Duration::from_secs(120))
.await;Implementations
Sourceimpl Client
impl Client
Constructs a fluent builder for the AddTagsToCertificate operation.
- The fluent builder is configurable:
certificate_arn(impl Into<String>)/set_certificate_arn(Option<String>):
required: trueString that contains the ARN of the ACM certificate to which the tag is to be applied. This must be of the form:
arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012For more information about ARNs, see Amazon Resource Names (ARNs).
tags(Tag)/set_tags(Option<Vec::<Tag>>):
required: trueThe key-value pair that defines the tag. The tag value is optional.
- On success, responds with
AddTagsToCertificateOutput - On failure, responds with
SdkError<AddTagsToCertificateError>
Sourceimpl Client
impl Client
Sourcepub fn create_acme_domain_validation(
&self,
) -> CreateAcmeDomainValidationFluentBuilder
pub fn create_acme_domain_validation( &self, ) -> CreateAcmeDomainValidationFluentBuilder
Constructs a fluent builder for the CreateAcmeDomainValidation operation.
- The fluent builder is configurable:
idempotency_token(impl Into<String>)/set_idempotency_token(Option<String>):
required: falseA unique, case-sensitive identifier to ensure idempotency of the request.
acme_endpoint_arn(impl Into<String>)/set_acme_endpoint_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME endpoint.
domain_name(impl Into<String>)/set_domain_name(Option<String>):
required: trueThe domain name to validate.
prevalidation_options(PrevalidationOptions)/set_prevalidation_options(Option<PrevalidationOptions>):
required: trueThe prevalidation options for the domain.
tags(Tag)/set_tags(Option<Vec::<Tag>>):
required: falseOne or more tags to associate with the domain validation.
- On success, responds with
CreateAcmeDomainValidationOutputwith field(s):acme_domain_validation_arn(String):The Amazon Resource Name (ARN) of the created domain validation.
- On failure, responds with
SdkError<CreateAcmeDomainValidationError>
Sourceimpl Client
impl Client
Sourcepub fn create_acme_endpoint(&self) -> CreateAcmeEndpointFluentBuilder
pub fn create_acme_endpoint(&self) -> CreateAcmeEndpointFluentBuilder
Constructs a fluent builder for the CreateAcmeEndpoint operation.
- The fluent builder is configurable:
idempotency_token(impl Into<String>)/set_idempotency_token(Option<String>):
required: falseA unique, case-sensitive identifier to ensure idempotency of the request.
authorization_behavior(AcmeAuthorizationBehavior)/set_authorization_behavior(Option<AcmeAuthorizationBehavior>):
required: trueThe authorization behavior for the ACME endpoint.
contact(AcmeContact)/set_contact(Option<AcmeContact>):
required: falseSpecifies whether ACME clients must provide contact information during account registration.
certificate_authority(CertificateAuthority)/set_certificate_authority(Option<CertificateAuthority>):
required: trueThe type of certificate authority to use for issuing certificates through this ACME endpoint.
tags(Tag)/set_tags(Option<Vec::<Tag>>):
required: falseOne or more tags to associate with the ACME endpoint.
certificate_tags(Tag)/set_certificate_tags(Option<Vec::<Tag>>):
required: falseTags to apply to certificates issued through this ACME endpoint.
- On success, responds with
CreateAcmeEndpointOutputwith field(s):acme_endpoint_arn(Option<String>):The Amazon Resource Name (ARN) of the created ACME endpoint.
- On failure, responds with
SdkError<CreateAcmeEndpointError>
Sourceimpl Client
impl Client
Sourcepub fn create_acme_external_account_binding(
&self,
) -> CreateAcmeExternalAccountBindingFluentBuilder
pub fn create_acme_external_account_binding( &self, ) -> CreateAcmeExternalAccountBindingFluentBuilder
Constructs a fluent builder for the CreateAcmeExternalAccountBinding operation.
- The fluent builder is configurable:
idempotency_token(impl Into<String>)/set_idempotency_token(Option<String>):
required: falseA unique, case-sensitive identifier to ensure idempotency of the request.
acme_endpoint_arn(impl Into<String>)/set_acme_endpoint_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME endpoint.
role_arn(impl Into<String>)/set_role_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the IAM role to associate with the external account binding.
expiration(Expiration)/set_expiration(Option<Expiration>):
required: falseThe expiration configuration for the external account binding.
tags(Tag)/set_tags(Option<Vec::<Tag>>):
required: falseOne or more tags to associate with the external account binding.
- On success, responds with
CreateAcmeExternalAccountBindingOutputwith field(s):external_account_binding(Option<AcmeExternalAccountBinding>):The created external account binding.
- On failure, responds with
SdkError<CreateAcmeExternalAccountBindingError>
Sourceimpl Client
impl Client
Sourcepub fn delete_acme_domain_validation(
&self,
) -> DeleteAcmeDomainValidationFluentBuilder
pub fn delete_acme_domain_validation( &self, ) -> DeleteAcmeDomainValidationFluentBuilder
Constructs a fluent builder for the DeleteAcmeDomainValidation operation.
- The fluent builder is configurable:
acme_domain_validation_arn(impl Into<String>)/set_acme_domain_validation_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME domain validation to delete.
- On success, responds with
DeleteAcmeDomainValidationOutput - On failure, responds with
SdkError<DeleteAcmeDomainValidationError>
Sourceimpl Client
impl Client
Sourcepub fn delete_acme_endpoint(&self) -> DeleteAcmeEndpointFluentBuilder
pub fn delete_acme_endpoint(&self) -> DeleteAcmeEndpointFluentBuilder
Constructs a fluent builder for the DeleteAcmeEndpoint operation.
- The fluent builder is configurable:
acme_endpoint_arn(impl Into<String>)/set_acme_endpoint_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME endpoint to delete.
- On success, responds with
DeleteAcmeEndpointOutput - On failure, responds with
SdkError<DeleteAcmeEndpointError>
Sourceimpl Client
impl Client
Sourcepub fn delete_acme_external_account_binding(
&self,
) -> DeleteAcmeExternalAccountBindingFluentBuilder
pub fn delete_acme_external_account_binding( &self, ) -> DeleteAcmeExternalAccountBindingFluentBuilder
Constructs a fluent builder for the DeleteAcmeExternalAccountBinding operation.
- The fluent builder is configurable:
acme_external_account_binding_arn(impl Into<String>)/set_acme_external_account_binding_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME external account binding to delete.
- On success, responds with
DeleteAcmeExternalAccountBindingOutput - On failure, responds with
SdkError<DeleteAcmeExternalAccountBindingError>
Sourceimpl Client
impl Client
Sourcepub fn delete_certificate(&self) -> DeleteCertificateFluentBuilder
pub fn delete_certificate(&self) -> DeleteCertificateFluentBuilder
Constructs a fluent builder for the DeleteCertificate operation.
- The fluent builder is configurable:
certificate_arn(impl Into<String>)/set_certificate_arn(Option<String>):
required: trueString that contains the ARN of the ACM certificate to be deleted. This must be of the form:
arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012For more information about ARNs, see Amazon Resource Names (ARNs).
- On success, responds with
DeleteCertificateOutput - On failure, responds with
SdkError<DeleteCertificateError>
Sourceimpl Client
impl Client
Sourcepub fn describe_acme_account(&self) -> DescribeAcmeAccountFluentBuilder
pub fn describe_acme_account(&self) -> DescribeAcmeAccountFluentBuilder
Constructs a fluent builder for the DescribeAcmeAccount operation.
- The fluent builder is configurable:
acme_endpoint_arn(impl Into<String>)/set_acme_endpoint_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME endpoint.
account_url(impl Into<String>)/set_account_url(Option<String>):
required: trueThe URL of the ACME account.
- On success, responds with
DescribeAcmeAccountOutputwith field(s):acme_account(Option<AcmeAccount>):The ACME account details.
- On failure, responds with
SdkError<DescribeAcmeAccountError>
Sourceimpl Client
impl Client
Sourcepub fn describe_acme_domain_validation(
&self,
) -> DescribeAcmeDomainValidationFluentBuilder
pub fn describe_acme_domain_validation( &self, ) -> DescribeAcmeDomainValidationFluentBuilder
Constructs a fluent builder for the DescribeAcmeDomainValidation operation.
- The fluent builder is configurable:
acme_domain_validation_arn(impl Into<String>)/set_acme_domain_validation_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME domain validation.
- On success, responds with
DescribeAcmeDomainValidationOutputwith field(s):acme_domain_validation(Option<AcmeDomainValidation>):The ACME domain validation details.
- On failure, responds with
SdkError<DescribeAcmeDomainValidationError>
Sourceimpl Client
impl Client
Sourcepub fn describe_acme_endpoint(&self) -> DescribeAcmeEndpointFluentBuilder
pub fn describe_acme_endpoint(&self) -> DescribeAcmeEndpointFluentBuilder
Constructs a fluent builder for the DescribeAcmeEndpoint operation.
- The fluent builder is configurable:
acme_endpoint_arn(impl Into<String>)/set_acme_endpoint_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME endpoint.
- On success, responds with
DescribeAcmeEndpointOutputwith field(s):acme_endpoint(Option<AcmeEndpoint>):The ACME endpoint details.
- On failure, responds with
SdkError<DescribeAcmeEndpointError>
Sourceimpl Client
impl Client
Sourcepub fn describe_acme_external_account_binding(
&self,
) -> DescribeAcmeExternalAccountBindingFluentBuilder
pub fn describe_acme_external_account_binding( &self, ) -> DescribeAcmeExternalAccountBindingFluentBuilder
Constructs a fluent builder for the DescribeAcmeExternalAccountBinding operation.
- The fluent builder is configurable:
acme_external_account_binding_arn(impl Into<String>)/set_acme_external_account_binding_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME external account binding.
- On success, responds with
DescribeAcmeExternalAccountBindingOutputwith field(s):external_account_binding(Option<AcmeExternalAccountBinding>):The external account binding details.
- On failure, responds with
SdkError<DescribeAcmeExternalAccountBindingError>
Sourceimpl Client
impl Client
Sourcepub fn describe_certificate(&self) -> DescribeCertificateFluentBuilder
pub fn describe_certificate(&self) -> DescribeCertificateFluentBuilder
Constructs a fluent builder for the DescribeCertificate operation.
- The fluent builder is configurable:
certificate_arn(impl Into<String>)/set_certificate_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACM certificate. The ARN must have the following form:
arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012For more information about ARNs, see Amazon Resource Names (ARNs).
- On success, responds with
DescribeCertificateOutputwith field(s):certificate(Option<CertificateDetail>):Metadata about an ACM certificate.
- On failure, responds with
SdkError<DescribeCertificateError>
Sourceimpl Client
impl Client
Sourcepub fn export_certificate(&self) -> ExportCertificateFluentBuilder
pub fn export_certificate(&self) -> ExportCertificateFluentBuilder
Constructs a fluent builder for the ExportCertificate operation.
- The fluent builder is configurable:
certificate_arn(impl Into<String>)/set_certificate_arn(Option<String>):
required: trueAn Amazon Resource Name (ARN) of the issued certificate. This must be of the form:
arn:aws:acm:region:account:certificate/12345678-1234-1234-1234-123456789012passphrase(Blob)/set_passphrase(Option<Blob>):
required: truePassphrase to associate with the encrypted exported private key.
When creating your passphrase, you can use any ASCII character except #, $, or %.
If you want to later decrypt the private key, you must have the passphrase. You can use the following OpenSSL command to decrypt a private key. After entering the command, you are prompted for the passphrase.
openssl rsa -in encrypted_key.pem -out decrypted_key.pem
- On success, responds with
ExportCertificateOutputwith field(s):certificate(Option<String>):The base64 PEM-encoded certificate.
certificate_chain(Option<String>):The base64 PEM-encoded certificate chain. This does not include the certificate that you are exporting.
private_key(Option<String>):The encrypted private key associated with the public key in the certificate. The key is output in PKCS #8 format and is base64 PEM-encoded.
- On failure, responds with
SdkError<ExportCertificateError>
Sourceimpl Client
impl Client
Sourcepub fn get_account_configuration(&self) -> GetAccountConfigurationFluentBuilder
pub fn get_account_configuration(&self) -> GetAccountConfigurationFluentBuilder
Constructs a fluent builder for the GetAccountConfiguration operation.
- The fluent builder takes no input, just
sendit. - On success, responds with
GetAccountConfigurationOutputwith field(s):expiry_events(Option<ExpiryEventsConfiguration>):Expiration events configuration options associated with the Amazon Web Services account.
- On failure, responds with
SdkError<GetAccountConfigurationError>
Sourceimpl Client
impl Client
Sourcepub fn get_acme_external_account_binding_credentials(
&self,
) -> GetAcmeExternalAccountBindingCredentialsFluentBuilder
pub fn get_acme_external_account_binding_credentials( &self, ) -> GetAcmeExternalAccountBindingCredentialsFluentBuilder
Constructs a fluent builder for the GetAcmeExternalAccountBindingCredentials operation.
- The fluent builder is configurable:
acme_external_account_binding_arn(impl Into<String>)/set_acme_external_account_binding_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME external account binding.
- On success, responds with
GetAcmeExternalAccountBindingCredentialsOutputwith field(s):key_id(Option<String>):The key identifier for the external account binding credentials.
mac_key(Option<String>):The MAC key for the external account binding credentials.
- On failure, responds with
SdkError<GetAcmeExternalAccountBindingCredentialsError>
Sourceimpl Client
impl Client
Sourcepub fn get_certificate(&self) -> GetCertificateFluentBuilder
pub fn get_certificate(&self) -> GetCertificateFluentBuilder
Constructs a fluent builder for the GetCertificate operation.
- The fluent builder is configurable:
certificate_arn(impl Into<String>)/set_certificate_arn(Option<String>):
required: trueString that contains a certificate ARN in the following format:
arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012For more information about ARNs, see Amazon Resource Names (ARNs).
- On success, responds with
GetCertificateOutputwith field(s):certificate(Option<String>):The ACM-issued certificate corresponding to the ARN specified as input.
certificate_chain(Option<String>):Certificates forming the requested certificate’s chain of trust. The chain consists of the certificate of the issuing CA and the intermediate certificates of any other subordinate CAs.
- On failure, responds with
SdkError<GetCertificateError>
Sourceimpl Client
impl Client
Sourcepub fn import_certificate(&self) -> ImportCertificateFluentBuilder
pub fn import_certificate(&self) -> ImportCertificateFluentBuilder
Constructs a fluent builder for the ImportCertificate operation.
- The fluent builder is configurable:
certificate_arn(impl Into<String>)/set_certificate_arn(Option<String>):
required: falseThe Amazon Resource Name (ARN) of an imported certificate to replace. To import a new certificate, omit this field.
certificate(Blob)/set_certificate(Option<Blob>):
required: trueThe certificate to import.
private_key(Blob)/set_private_key(Option<Blob>):
required: trueThe private key that matches the public key in the certificate.
certificate_chain(Blob)/set_certificate_chain(Option<Blob>):
required: falseThe PEM encoded certificate chain.
tags(Tag)/set_tags(Option<Vec::<Tag>>):
required: falseOne or more resource tags to associate with the imported certificate.
Note: You cannot apply tags when reimporting a certificate.
- On success, responds with
ImportCertificateOutputwith field(s):certificate_arn(Option<String>):The Amazon Resource Name (ARN) of the imported certificate.
- On failure, responds with
SdkError<ImportCertificateError>
Sourceimpl Client
impl Client
Sourcepub fn list_acme_accounts(&self) -> ListAcmeAccountsFluentBuilder
pub fn list_acme_accounts(&self) -> ListAcmeAccountsFluentBuilder
Constructs a fluent builder for the ListAcmeAccounts operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseA token for pagination.
max_results(i32)/set_max_results(Option<i32>):
required: falseThe maximum number of results to return.
acme_endpoint_arn(impl Into<String>)/set_acme_endpoint_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME endpoint.
- On success, responds with
ListAcmeAccountsOutputwith field(s):acme_accounts(Option<Vec::<AcmeAccountSummary>>):The list of ACME accounts.
next_token(Option<String>):A token for pagination.
- On failure, responds with
SdkError<ListAcmeAccountsError>
Sourceimpl Client
impl Client
Sourcepub fn list_acme_domain_validations(
&self,
) -> ListAcmeDomainValidationsFluentBuilder
pub fn list_acme_domain_validations( &self, ) -> ListAcmeDomainValidationsFluentBuilder
Constructs a fluent builder for the ListAcmeDomainValidations operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseA token for pagination.
max_results(i32)/set_max_results(Option<i32>):
required: falseThe maximum number of results to return.
acme_endpoint_arn(impl Into<String>)/set_acme_endpoint_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME endpoint.
- On success, responds with
ListAcmeDomainValidationsOutputwith field(s):acme_domain_validations(Option<Vec::<AcmeDomainValidationSummary>>):The list of domain validations.
next_token(Option<String>):A token for pagination.
- On failure, responds with
SdkError<ListAcmeDomainValidationsError>
Sourceimpl Client
impl Client
Sourcepub fn list_acme_endpoints(&self) -> ListAcmeEndpointsFluentBuilder
pub fn list_acme_endpoints(&self) -> ListAcmeEndpointsFluentBuilder
Constructs a fluent builder for the ListAcmeEndpoints operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseA token for pagination.
max_results(i32)/set_max_results(Option<i32>):
required: falseThe maximum number of results to return.
- On success, responds with
ListAcmeEndpointsOutputwith field(s):acme_endpoints(Option<Vec::<AcmeEndpointSummary>>):The list of ACME endpoints.
next_token(Option<String>):A token for pagination.
- On failure, responds with
SdkError<ListAcmeEndpointsError>
Sourceimpl Client
impl Client
Sourcepub fn list_acme_external_account_bindings(
&self,
) -> ListAcmeExternalAccountBindingsFluentBuilder
pub fn list_acme_external_account_bindings( &self, ) -> ListAcmeExternalAccountBindingsFluentBuilder
Constructs a fluent builder for the ListAcmeExternalAccountBindings operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseA token for pagination.
max_results(i32)/set_max_results(Option<i32>):
required: falseThe maximum number of results to return.
acme_endpoint_arn(impl Into<String>)/set_acme_endpoint_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME endpoint.
- On success, responds with
ListAcmeExternalAccountBindingsOutputwith field(s):external_account_bindings(Option<Vec::<AcmeExternalAccountBindingSummary>>):The list of external account bindings.
next_token(Option<String>):A token for pagination.
- On failure, responds with
SdkError<ListAcmeExternalAccountBindingsError>
Sourceimpl Client
impl Client
Sourcepub fn list_certificate_domain_validations(
&self,
) -> ListCertificateDomainValidationsFluentBuilder
pub fn list_certificate_domain_validations( &self, ) -> ListCertificateDomainValidationsFluentBuilder
Constructs a fluent builder for the ListCertificateDomainValidations operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
certificate_arn(impl Into<String>)/set_certificate_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the certificate for which to list domain validation summaries.
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseA token returned by a previous call to
ListCertificateDomainValidations. If the number of results exceedsMaxItems, use this token to retrieve the next page of results.max_items(i32)/set_max_items(Option<i32>):
required: falseThe maximum number of domain validation summaries to return. If you don’t specify a value, the default is 1000.
- On success, responds with
ListCertificateDomainValidationsOutputwith field(s):domain_validation_summary_list(Option<Vec::<DomainValidationSummary>>):A list of
DomainValidationSummaryobjects, one for each domain on the certificate. Each object contains the domain name and its active and requested validation configurations.next_token(Option<String>):If the number of results exceeds
MaxItems, this token is included in the response. Use this token in a subsequentListCertificateDomainValidationsrequest to retrieve the next page of results.
- On failure, responds with
SdkError<ListCertificateDomainValidationsError>
Sourceimpl Client
impl Client
Sourcepub fn list_certificates(&self) -> ListCertificatesFluentBuilder
pub fn list_certificates(&self) -> ListCertificatesFluentBuilder
Constructs a fluent builder for the ListCertificates operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
certificate_statuses(CertificateStatus)/set_certificate_statuses(Option<Vec::<CertificateStatus>>):
required: falseFilter the certificate list by status value.
certificate_key_pair_origins(CertificateKeyPairOrigin)/set_certificate_key_pair_origins(Option<Vec::<CertificateKeyPairOrigin>>):
required: falseFilter the certificate list by certificate key pair origin. Specify one or more
CertificateKeyPairOriginvalues. Default filtering returns only certificates with key pair origin ofAWS_MANAGEDandCUSTOMER_PROVIDED.includes(Filters)/set_includes(Option<Filters>):
required: falseFilter the certificate list. For more information, see the
Filtersstructure.next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseUse this parameter only when paginating results and only in a subsequent request after you receive a response with truncated results. Set it to the value of
NextTokenfrom the response you just received.max_items(i32)/set_max_items(Option<i32>):
required: falseUse this parameter when paginating results to specify the maximum number of items to return in the response. If additional items exist beyond the number you specify, the
NextTokenelement is sent in the response. Use thisNextTokenvalue in a subsequent request to retrieve additional items.sort_by(SortBy)/set_sort_by(Option<SortBy>):
required: falseSpecifies the field to sort results by. If you specify
SortBy, you must also specifySortOrder.sort_order(SortOrder)/set_sort_order(Option<SortOrder>):
required: falseSpecifies the order of sorted results. If you specify
SortOrder, you must also specifySortBy.
- On success, responds with
ListCertificatesOutputwith field(s):next_token(Option<String>):When the list is truncated, this value is present and contains the value to use for the
NextTokenparameter in a subsequent pagination request.certificate_summary_list(Option<Vec::<CertificateSummary>>):A list of ACM certificates.
- On failure, responds with
SdkError<ListCertificatesError>
Sourceimpl Client
impl Client
Constructs a fluent builder for the ListTagsForCertificate operation.
- The fluent builder is configurable:
certificate_arn(impl Into<String>)/set_certificate_arn(Option<String>):
required: trueString that contains the ARN of the ACM certificate for which you want to list the tags. This must have the following form:
arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012For more information about ARNs, see Amazon Resource Names (ARNs).
- On success, responds with
ListTagsForCertificateOutputwith field(s):tags(Option<Vec::<Tag>>):The key-value pairs that define the applied tags.
- On failure, responds with
SdkError<ListTagsForCertificateError>
Sourceimpl Client
impl Client
Constructs a fluent builder for the ListTagsForResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: trueThe ARN of the ACM resource for which to list tags.
- On success, responds with
ListTagsForResourceOutputwith field(s):tags(Option<Vec::<Tag>>):The tags associated with the resource.
- On failure, responds with
SdkError<ListTagsForResourceError>
Sourceimpl Client
impl Client
Sourcepub fn put_account_configuration(&self) -> PutAccountConfigurationFluentBuilder
pub fn put_account_configuration(&self) -> PutAccountConfigurationFluentBuilder
Constructs a fluent builder for the PutAccountConfiguration operation.
- The fluent builder is configurable:
expiry_events(ExpiryEventsConfiguration)/set_expiry_events(Option<ExpiryEventsConfiguration>):
required: falseSpecifies expiration events associated with an account.
idempotency_token(impl Into<String>)/set_idempotency_token(Option<String>):
required: trueCustomer-chosen string used to distinguish between calls to
PutAccountConfiguration. Idempotency tokens time out after one hour. If you callPutAccountConfigurationmultiple times with the same unexpired idempotency token, ACM treats it as the same request and returns the original result. If you change the idempotency token for each call, ACM treats each call as a new request.
- On success, responds with
PutAccountConfigurationOutput - On failure, responds with
SdkError<PutAccountConfigurationError>
Sourceimpl Client
impl Client
Constructs a fluent builder for the RemoveTagsFromCertificate operation.
- The fluent builder is configurable:
certificate_arn(impl Into<String>)/set_certificate_arn(Option<String>):
required: trueString that contains the ARN of the ACM Certificate with one or more tags that you want to remove. This must be of the form:
arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012For more information about ARNs, see Amazon Resource Names (ARNs).
tags(Tag)/set_tags(Option<Vec::<Tag>>):
required: trueThe key-value pair that defines the tag to remove.
- On success, responds with
RemoveTagsFromCertificateOutput - On failure, responds with
SdkError<RemoveTagsFromCertificateError>
Sourceimpl Client
impl Client
Sourcepub fn renew_certificate(&self) -> RenewCertificateFluentBuilder
pub fn renew_certificate(&self) -> RenewCertificateFluentBuilder
Constructs a fluent builder for the RenewCertificate operation.
- The fluent builder is configurable:
certificate_arn(impl Into<String>)/set_certificate_arn(Option<String>):
required: trueString that contains the ARN of the ACM certificate to be renewed. This must be of the form:
arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012For more information about ARNs, see Amazon Resource Names (ARNs).
- On success, responds with
RenewCertificateOutput - On failure, responds with
SdkError<RenewCertificateError>
Sourceimpl Client
impl Client
Sourcepub fn request_certificate(&self) -> RequestCertificateFluentBuilder
pub fn request_certificate(&self) -> RequestCertificateFluentBuilder
Constructs a fluent builder for the RequestCertificate operation.
- The fluent builder is configurable:
domain_name(impl Into<String>)/set_domain_name(Option<String>):
required: trueFully qualified domain name (FQDN), such as www.example.com, that you want to secure with an ACM certificate. Use an asterisk (*) to create a wildcard certificate that protects several sites in the same domain. For example, *.example.com protects www.example.com, site.example.com, and images.example.com.
In compliance with RFC 5280, the length of the domain name (technically, the Common Name) that you provide cannot exceed 64 octets (characters), including periods. To add a longer domain name, specify it in the Subject Alternative Name field, which supports names up to 253 octets in length.
validation_method(ValidationMethod)/set_validation_method(Option<ValidationMethod>):
required: falseThe method you want to use if you are requesting a public certificate to validate that you own or control domain. You can validate with DNS or validate with email. We recommend that you use DNS validation.
subject_alternative_names(impl Into<String>)/set_subject_alternative_names(Option<Vec::<String>>):
required: falseAdditional FQDNs to be included in the Subject Alternative Name extension of the ACM certificate. For example, add the name www.example.net to a certificate for which the
DomainNamefield is www.example.com if users can reach your site by using either name. The maximum number of domain names that you can add to an ACM certificate is 100. However, the initial quota is 10 domain names. If you need more than 10 names, you must request a quota increase. For more information, see Quotas.The maximum length of a SAN DNS name is 253 octets. The name is made up of multiple labels separated by periods. No label can be longer than 63 octets. Consider the following examples:
-
(63 octets).(63 octets).(63 octets).(61 octets)is legal because the total length is 253 octets (63+1+63+1+63+1+61) and no label exceeds 63 octets. -
(64 octets).(63 octets).(63 octets).(61 octets)is not legal because the total length exceeds 253 octets (64+1+63+1+63+1+61) and the first label exceeds 63 octets. -
(63 octets).(63 octets).(63 octets).(62 octets)is not legal because the total length of the DNS name (63+1+63+1+63+1+62) exceeds 253 octets.
-
idempotency_token(impl Into<String>)/set_idempotency_token(Option<String>):
required: falseCustomer chosen string that can be used to distinguish between calls to
RequestCertificate. Idempotency tokens time out after one hour. Therefore, if you callRequestCertificatemultiple times with the same idempotency token within one hour, ACM recognizes that you are requesting only one certificate and will issue only one. If you change the idempotency token for each call, ACM recognizes that you are requesting multiple certificates.domain_validation_options(DomainValidationOption)/set_domain_validation_options(Option<Vec::<DomainValidationOption>>):
required: falseThe domain name that you want ACM to use to send you emails so that you can validate domain ownership.
options(CertificateOptions)/set_options(Option<CertificateOptions>):
required: falseYou can use this parameter to specify whether to export your certificate.
Certificate transparency logging opt-out is no longer available. All public certificates are recorded in a certificate transparency log. For more information, see Certificate Transparency Logging.
You can export public ACM certificates to use with Amazon Web Services services as well as outside the Amazon Web Services Cloud. For more information, see Certificate Manager exportable public certificate.
certificate_authority_arn(impl Into<String>)/set_certificate_authority_arn(Option<String>):
required: falseThe Amazon Resource Name (ARN) of the private certificate authority (CA) that will be used to issue the certificate. If you do not provide an ARN and you are trying to request a private certificate, ACM will attempt to issue a public certificate. For more information about private CAs, see the Amazon Web Services Private Certificate Authority user guide. The ARN must have the following form:
arn:aws:acm-pca:region:account:certificate-authority/12345678-1234-1234-1234-123456789012tags(Tag)/set_tags(Option<Vec::<Tag>>):
required: falseOne or more resource tags to associate with the certificate.
key_algorithm(KeyAlgorithm)/set_key_algorithm(Option<KeyAlgorithm>):
required: falseSpecifies the algorithm of the public and private key pair that your certificate uses to encrypt data. RSA is the default key algorithm for ACM certificates. Elliptic Curve Digital Signature Algorithm (ECDSA) keys are smaller, offering security comparable to RSA keys but with greater computing efficiency. However, ECDSA is not supported by all network clients. Some Amazon Web Services services may require RSA keys, or only support ECDSA keys of a particular size, while others allow the use of either RSA and ECDSA keys to ensure that compatibility is not broken. Check the requirements for the Amazon Web Services service where you plan to deploy your certificate. For more information about selecting an algorithm, see Key algorithms.
Algorithms supported for an ACM certificate request include:
-
RSA_2048 -
EC_prime256v1 -
EC_secp384r1
Other listed algorithms are for imported certificates only.
When you request a private PKI certificate signed by a CA from Amazon Web Services Private CA, the specified signing algorithm family (RSA or ECDSA) must match the algorithm family of the CA’s secret key.
Default: RSA_2048
-
managed_by(CertificateManagedBy)/set_managed_by(Option<CertificateManagedBy>):
required: falseIdentifies the Amazon Web Services service that manages the certificate issued by ACM.
- On success, responds with
RequestCertificateOutputwith field(s):certificate_arn(Option<String>):String that contains the ARN of the issued certificate. This must be of the form:
arn:aws:acm:us-east-1:123456789012:certificate/12345678-1234-1234-1234-123456789012
- On failure, responds with
SdkError<RequestCertificateError>
Sourceimpl Client
impl Client
Sourcepub fn resend_validation_email(&self) -> ResendValidationEmailFluentBuilder
pub fn resend_validation_email(&self) -> ResendValidationEmailFluentBuilder
Constructs a fluent builder for the ResendValidationEmail operation.
- The fluent builder is configurable:
certificate_arn(impl Into<String>)/set_certificate_arn(Option<String>):
required: trueString that contains the ARN of the requested certificate. The certificate ARN is generated and returned by the
RequestCertificateaction as soon as the request is made. By default, using this parameter causes email to be sent to all top-level domains you specified in the certificate request. The ARN must be of the form:arn:aws:acm:us-east-1:123456789012:certificate/12345678-1234-1234-1234-123456789012domain(impl Into<String>)/set_domain(Option<String>):
required: trueThe fully qualified domain name (FQDN) of the certificate that needs to be validated.
validation_domain(impl Into<String>)/set_validation_domain(Option<String>):
required: trueThe base validation domain that will act as the suffix of the email addresses that are used to send the emails. This must be the same as the
Domainvalue or a superdomain of theDomainvalue. For example, if you requested a certificate forsite.subdomain.example.comand specify a ValidationDomain ofsubdomain.example.com, ACM sends email to the the following five addresses:-
admin@subdomain.example.com
-
administrator@subdomain.example.com
-
hostmaster@subdomain.example.com
-
postmaster@subdomain.example.com
-
webmaster@subdomain.example.com
-
- On success, responds with
ResendValidationEmailOutput - On failure, responds with
SdkError<ResendValidationEmailError>
Sourceimpl Client
impl Client
Sourcepub fn revoke_acme_account(&self) -> RevokeAcmeAccountFluentBuilder
pub fn revoke_acme_account(&self) -> RevokeAcmeAccountFluentBuilder
Constructs a fluent builder for the RevokeAcmeAccount operation.
- The fluent builder is configurable:
acme_endpoint_arn(impl Into<String>)/set_acme_endpoint_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME endpoint.
account_url(impl Into<String>)/set_account_url(Option<String>):
required: trueThe URL of the ACME account to revoke.
- On success, responds with
RevokeAcmeAccountOutput - On failure, responds with
SdkError<RevokeAcmeAccountError>
Sourceimpl Client
impl Client
Sourcepub fn revoke_acme_external_account_binding(
&self,
) -> RevokeAcmeExternalAccountBindingFluentBuilder
pub fn revoke_acme_external_account_binding( &self, ) -> RevokeAcmeExternalAccountBindingFluentBuilder
Constructs a fluent builder for the RevokeAcmeExternalAccountBinding operation.
- The fluent builder is configurable:
acme_external_account_binding_arn(impl Into<String>)/set_acme_external_account_binding_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME external account binding to revoke.
- On success, responds with
RevokeAcmeExternalAccountBindingOutput - On failure, responds with
SdkError<RevokeAcmeExternalAccountBindingError>
Sourceimpl Client
impl Client
Sourcepub fn revoke_certificate(&self) -> RevokeCertificateFluentBuilder
pub fn revoke_certificate(&self) -> RevokeCertificateFluentBuilder
Constructs a fluent builder for the RevokeCertificate operation.
- The fluent builder is configurable:
certificate_arn(impl Into<String>)/set_certificate_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the public or private certificate that will be revoked. The ARN must have the following form:
arn:aws:acm:region:account:certificate/12345678-1234-1234-1234-123456789012revocation_reason(RevocationReason)/set_revocation_reason(Option<RevocationReason>):
required: trueSpecifies why you revoked the certificate.
- On success, responds with
RevokeCertificateOutputwith field(s):certificate_arn(Option<String>):The Amazon Resource Name (ARN) of the public or private certificate that was revoked.
- On failure, responds with
SdkError<RevokeCertificateError>
Sourceimpl Client
impl Client
Sourcepub fn search_certificates(&self) -> SearchCertificatesFluentBuilder
pub fn search_certificates(&self) -> SearchCertificatesFluentBuilder
Constructs a fluent builder for the SearchCertificates operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
filter_statement(CertificateFilterStatement)/set_filter_statement(Option<CertificateFilterStatement>):
required: falseA filter statement that defines the search criteria. You can combine multiple filters using AND, OR, and NOT logical operators to create complex queries.
max_results(i32)/set_max_results(Option<i32>):
required: falseThe maximum number of results to return in the response. Default is 100.
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseUse this parameter only when paginating results and only in a subsequent request after you receive a response with truncated results. Set it to the value of
NextTokenfrom the response you just received.sort_by(SearchCertificatesSortBy)/set_sort_by(Option<SearchCertificatesSortBy>):
required: falseSpecifies the field to sort results by. Valid values are CREATED_AT, NOT_AFTER, STATUS, RENEWAL_STATUS, EXPORTED, IN_USE, NOT_BEFORE, KEY_ALGORITHM, TYPE, CERTIFICATE_ARN, COMMON_NAME, REVOKED_AT, RENEWAL_ELIGIBILITY, ISSUED_AT, MANAGED_BY, EXPORT_OPTION, VALIDATION_METHOD, and IMPORTED_AT.
sort_order(SearchCertificatesSortOrder)/set_sort_order(Option<SearchCertificatesSortOrder>):
required: falseSpecifies the order of sorted results. Valid values are ASCENDING or DESCENDING.
- On success, responds with
SearchCertificatesOutputwith field(s):results(Option<Vec::<CertificateSearchResult>>):A list of certificate search results containing certificate ARNs, X.509 attributes, and ACM metadata.
next_token(Option<String>):When the list is truncated, this value is present and contains the value to use for the
NextTokenparameter in a subsequent pagination request.
- On failure, responds with
SdkError<SearchCertificatesError>
Sourceimpl Client
impl Client
Sourcepub fn tag_resource(&self) -> TagResourceFluentBuilder
pub fn tag_resource(&self) -> TagResourceFluentBuilder
Constructs a fluent builder for the TagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: trueThe ARN of the ACM resource to which the tag is to be applied.
tags(Tag)/set_tags(Option<Vec::<Tag>>):
required: trueThe key-value pair that defines the tag to apply.
- On success, responds with
TagResourceOutput - On failure, responds with
SdkError<TagResourceError>
Sourceimpl Client
impl Client
Sourcepub fn untag_resource(&self) -> UntagResourceFluentBuilder
pub fn untag_resource(&self) -> UntagResourceFluentBuilder
Constructs a fluent builder for the UntagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: trueThe ARN of the ACM resource from which the tag is to be removed.
tag_keys(impl Into<String>)/set_tag_keys(Option<Vec::<String>>):
required: trueThe key of each tag to remove.
- On success, responds with
UntagResourceOutput - On failure, responds with
SdkError<UntagResourceError>
Sourceimpl Client
impl Client
Sourcepub fn update_acme_domain_validation(
&self,
) -> UpdateAcmeDomainValidationFluentBuilder
pub fn update_acme_domain_validation( &self, ) -> UpdateAcmeDomainValidationFluentBuilder
Constructs a fluent builder for the UpdateAcmeDomainValidation operation.
- The fluent builder is configurable:
acme_domain_validation_arn(impl Into<String>)/set_acme_domain_validation_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME domain validation to update.
prevalidation_options(PrevalidationOptions)/set_prevalidation_options(Option<PrevalidationOptions>):
required: falseThe updated prevalidation options.
- On success, responds with
UpdateAcmeDomainValidationOutput - On failure, responds with
SdkError<UpdateAcmeDomainValidationError>
Sourceimpl Client
impl Client
Sourcepub fn update_acme_endpoint(&self) -> UpdateAcmeEndpointFluentBuilder
pub fn update_acme_endpoint(&self) -> UpdateAcmeEndpointFluentBuilder
Constructs a fluent builder for the UpdateAcmeEndpoint operation.
- The fluent builder is configurable:
acme_endpoint_arn(impl Into<String>)/set_acme_endpoint_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the ACME endpoint to update.
authorization_behavior(AcmeAuthorizationBehavior)/set_authorization_behavior(Option<AcmeAuthorizationBehavior>):
required: falseThe updated authorization behavior.
contact(AcmeContact)/set_contact(Option<AcmeContact>):
required: falseThe updated contact requirement.
certificate_authority(CertificateAuthority)/set_certificate_authority(Option<CertificateAuthority>):
required: falseThe updated certificate authority configuration.
- On success, responds with
UpdateAcmeEndpointOutput - On failure, responds with
SdkError<UpdateAcmeEndpointError>
Sourceimpl Client
impl Client
Sourcepub fn update_certificate_options(
&self,
) -> UpdateCertificateOptionsFluentBuilder
pub fn update_certificate_options( &self, ) -> UpdateCertificateOptionsFluentBuilder
Constructs a fluent builder for the UpdateCertificateOptions operation.
- The fluent builder is configurable:
certificate_arn(impl Into<String>)/set_certificate_arn(Option<String>):
required: trueARN of the requested certificate to update. This must be of the form:
arn:aws:acm:us-east-1:account:certificate/12345678-1234-1234-1234-123456789012options(CertificateOptions)/set_options(Option<CertificateOptions>):
required: trueUse to update the options for your certificate. Currently, you can change the domain validation method or specify whether to export your certificate. For more information about migrating from email to DNS validation, see Migrate from email to DNS validation.
- On success, responds with
UpdateCertificateOptionsOutput - On failure, responds with
SdkError<UpdateCertificateOptionsError>
Sourceimpl Client
impl Client
Sourcepub fn from_conf(conf: Config) -> Self
pub fn from_conf(conf: Config) -> Self
Creates a new client from the service Config.
Panics
This method will panic in the following cases:
- Retries or timeouts are enabled without a
sleep_implconfigured. - Identity caching is enabled without a
sleep_implandtime_sourceconfigured. - No
behavior_versionis provided.
The panic message for each of these will have instructions on how to resolve them.
Sourceimpl Client
impl Client
Sourcepub fn new(sdk_config: &SdkConfig) -> Self
pub fn new(sdk_config: &SdkConfig) -> Self
Creates a new client from an SDK Config.
Panics
- This method will panic if the
sdk_configis missing an async sleep implementation. If you experience this panic, set thesleep_implon the Config passed into this function to fix it. - This method will panic if the
sdk_configis missing an HTTP connector. If you experience this panic, set thehttp_connectoron the Config passed into this function to fix it. - This method will panic if no
BehaviorVersionis provided. If you experience this panic, setbehavior_versionon the Config or enable thebehavior-version-latestCargo feature.